# Generated by Django 5.2.7 on 2026-01-05 01:25

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("tag_me", "0004_fk_lookup_refactor"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="taggedfieldmodel",
            name="unique_tagged_field_model",
        ),
        migrations.AlterField(
            model_name="taggedfieldmodel",
            name="tag_type",
            field=models.CharField(
                default="user",
                editable=False,
                help_text="This is the tag type, default is 'user'.",
                max_length=20,
                verbose_name="Tag type",
            ),
        ),
        migrations.AddConstraint(
            model_name="systemtag",
            constraint=models.UniqueConstraint(
                condition=models.Q(("tagged_field__isnull", False)),
                fields=("tagged_field",),
                name="unique_system_tag_field",
            ),
        ),
        # NOTE: The unique_tagged_field_content_field constraint is now
        # properly added in 0004 using migrations.AddConstraint.
        # It was removed from here to avoid duplicate constraint errors.
    ]
