from .views import (
    MgmtUserTagListView,
    SynchronisedTagFieldListView,
    TagFieldListView,
    TaggedFieldEditView,
    TagManagementView,
    UserTagEditView,
    UserTagListView,
    WidgetAddUserTagView,
)

__all__ = [
    "MgmtUserTagListView",
    "SynchronisedTagFieldListView",
    "TagFieldListView",
    "TaggedFieldEditView",
    "TagManagementView",
    "UserTagEditView",
    "UserTagListView",
    "WidgetAddUserTagView",
]
