# Generated by Django 5.2.7 on 2026-01-04 10:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("tests", "0003_alter_tagtestbase_tags"),
    ]

    operations = [
        migrations.AddField(
            model_name="tagtestbase",
            name="search_tags",
            field=models.TextField(
                blank=True,
                default="",
                help_text="A list of every tag created, for use in search tools",
                verbose_name="Search Tags",
            ),
        ),
        migrations.AlterField(
            model_name="tagtestbase",
            name="tags",
            field=models.CharField(
                blank=True,
                default="",
                help_text="The tags that are considered active and in use by the user",
                max_length=255,
                null=True,
                verbose_name="tags",
            ),
        ),
    ]
