"""Custom Users APP configuration file."""

from django.apps import AppConfig


class UsersConfig(AppConfig):
    """Custom Users Configuration class"""

    default_auto_field = "django.db.models.BigAutoField"
    name = "users"
